==> bw2io-0.8.12-py3-none-any.whl: bw2io/strategies/__init__.py <==
# -*- coding: utf-8 -*-
__all__ = [
    "add_activity_hash_code",
    "add_cpc_classification_from_single_reference_product",
    "add_database_name",
    "assign_only_product_as_production",
    "assign_single_product_as_activity",
    "change_electricity_unit_mj_to_kwh",
    "clean_integer_codes",
    "convert_activity_parameters_to_list",
    "convert_uncertainty_types_to_integers",
    "create_composite_code",
    "csv_add_missing_exchanges_section",
    "csv_drop_unknown",
    "csv_numerize",
    "csv_restore_booleans",
    "csv_restore_tuples",
    "delete_exchanges_missing_activity",
    "delete_ghost_exchanges",
    "delete_integer_codes",
    "delete_none_synonyms",
    "drop_falsey_uncertainty_fields_but_keep_zeros",
    "drop_temporary_outdated_biosphere_flows",
    "drop_unlinked",
    "drop_unlinked_cfs",
    "drop_unspecified_subcategories",
    "ensure_categories_are_tuples",
    "es1_allocate_multioutput",
    "es2_assign_only_product_with_amount_as_reference_product",
    "fix_ecoinvent_flows_pre35",
    "fix_localized_water_flows",
    "fix_unreasonably_high_lognormal_uncertainties",
    "fix_zero_allocation_products",
    "link_biosphere_by_flow_uuid",
    "link_internal_technosphere_by_composite_code",
    "link_iterable_by_fields",
    "link_technosphere_based_on_name_unit_location",
    "link_technosphere_by_activity_hash",
    "match_subcategories",
    "migrate_datasets",
    "migrate_exchanges",
    "normalize_biosphere_categories",
    "normalize_biosphere_names",
    "normalize_simapro_biosphere_categories",
    "normalize_simapro_biosphere_names",
    "normalize_units",
    "remove_uncertainty_from_negative_loss_exchanges",
    "remove_unnamed_parameters",
    "remove_zero_amount_coproducts",
    "remove_zero_amount_inputs_with_no_activity",
    "reparametrize_lognormal_to_agree_with_static_amount",
    "set_biosphere_type",
    "set_code_by_activity_hash",
    "set_lognormal_loc_value",
    "sp_allocate_products",
    "special",
    "split_exchanges",
    "split_simapro_name_geo",
    "strip_biosphere_exc_locations",
    "tupleize_categories",
    "update_ecoinvent_locations",
    "update_social_flows_in_older_consequential",
]


from .biosphere import (
    drop_unspecified_subcategories,
    ensure_categories_are_tuples,
    normalize_biosphere_categories,
    normalize_biosphere_names,
    strip_biosphere_exc_locations,
)
from .csv import (
    csv_add_missing_exchanges_section,
    csv_drop_unknown,
    csv_numerize,
    csv_restore_booleans,
    csv_restore_tuples,
)
from .ecospold1_allocation import (
    clean_integer_codes,
    delete_integer_codes,
    es1_allocate_multioutput,
)
from .ecospold2 import (
    add_cpc_classification_from_single_reference_product,
    assign_single_product_as_activity,
    create_composite_code,
    delete_exchanges_missing_activity,
    delete_ghost_exchanges,
    delete_none_synonyms,
    drop_temporary_outdated_biosphere_flows,
    es2_assign_only_product_with_amount_as_reference_product,
    fix_ecoinvent_flows_pre35,
    fix_unreasonably_high_lognormal_uncertainties,
    link_biosphere_by_flow_uuid,
    link_internal_technosphere_by_composite_code,
    remove_uncertainty_from_negative_loss_exchanges,
    remove_unnamed_parameters,
    remove_zero_amount_coproducts,
    remove_zero_amount_inputs_with_no_activity,
    reparametrize_lognormal_to_agree_with_static_amount,
    set_lognormal_loc_value,
    update_social_flows_in_older_consequential,
)
from .generic import (
    add_database_name,
    assign_only_product_as_production,
    convert_activity_parameters_to_list,
    convert_uncertainty_types_to_integers,
    drop_falsey_uncertainty_fields_but_keep_zeros,
    drop_unlinked,
    link_iterable_by_fields,
    link_technosphere_by_activity_hash,
    normalize_units,
    set_code_by_activity_hash,
    split_exchanges,
    tupleize_categories,
)
from .lcia import (
    add_activity_hash_code,
    drop_unlinked_cfs,
    rationalize_method_names,
    set_biosphere_type,
    match_subcategories,
)
from .migrations import (
    migrate_datasets,
    migrate_exchanges,
)
from .simapro import (
    change_electricity_unit_mj_to_kwh,
    fix_localized_water_flows,
    fix_zero_allocation_products,
    link_technosphere_based_on_name_unit_location,
    normalize_simapro_biosphere_categories,
    normalize_simapro_biosphere_names,
    sp_allocate_products,
    split_simapro_name_geo,
)
from .locations import update_ecoinvent_locations
from . import special

==> bw2io-0.9.dev38-py3-none-any.whl: bw2io/strategies/__init__.py <==
__all__ = [
    "add_activity_hash_code",
    "add_cpc_classification_from_single_reference_product",
    "add_database_name",
    "assign_only_product_as_production",
    "assign_single_product_as_activity",
    "change_electricity_unit_mj_to_kwh",
    "clean_integer_codes",
    "convert_activity_parameters_to_list",
    "convert_uncertainty_types_to_integers",
    "create_composite_code",
    "create_products_as_new_nodes",
    "csv_add_missing_exchanges_section",
    "csv_drop_unknown",
    "csv_numerize",
    "csv_restore_booleans",
    "csv_restore_tuples",
    "delete_exchanges_missing_activity",
    "delete_ghost_exchanges",
    "delete_integer_codes",
    "delete_none_synonyms",
    "drop_falsey_uncertainty_fields_but_keep_zeros",
    "drop_temporary_outdated_biosphere_flows",
    "drop_unlinked",
    "drop_unlinked_cfs",
    "drop_unspecified_subcategories",
    "ensure_categories_are_tuples",
    "es1_allocate_multioutput",
    "es2_assign_only_product_with_amount_as_reference_product",
    "fix_ecoinvent_flows_pre35",
    "fix_localized_water_flows",
    "fix_unreasonably_high_lognormal_uncertainties",
    "fix_zero_allocation_products",
    "json_ld_add_activity_unit",
    "json_ld_add_products_as_activities",
    "json_ld_allocate_datasets",
    "json_ld_convert_unit_to_reference_unit",
    "json_ld_fix_process_type",
    "json_ld_get_activities_list_from_rawdata",
    "json_ld_get_normalized_exchange_locations",
    "json_ld_get_normalized_exchange_units",
    "json_ld_label_exchange_type",
    "json_ld_lcia_add_method_metadata",
    "json_ld_lcia_convert_to_list",
    "json_ld_lcia_reformat_cfs_as_exchanges",
    "json_ld_lcia_set_method_metadata",
    "json_ld_location_name",
    "json_ld_prepare_exchange_fields_for_linking",
    "json_ld_remove_fields",
    "json_ld_rename_metadata_fields",
    "link_biosphere_by_flow_uuid",
    "link_internal_technosphere_by_composite_code",
    "link_iterable_by_fields",
    "link_technosphere_based_on_name_unit_location",
    "link_technosphere_by_activity_hash",
    "match_against_only_available_in_given_context_tree",
    "match_against_top_level_context",
    "match_internal_simapro_simapro_with_unit_conversion",
    "match_subcategories",
    "migrate_datasets",
    "migrate_exchanges",
    "normalize_biosphere_categories",
    "normalize_biosphere_names",
    "normalize_simapro_biosphere_categories",
    "normalize_simapro_biosphere_names",
    "normalize_simapro_labels_to_brightway_standard",
    "normalize_units",
    "override_process_name_using_single_functional_exchange",
    "remove_random_exchanges",
    "remove_uncertainty_from_negative_loss_exchanges",
    "remove_unnamed_parameters",
    "remove_useeio_products",
    "remove_zero_amount_coproducts",
    "remove_zero_amount_inputs_with_no_activity",
    "reparametrize_lognormal_to_agree_with_static_amount",
    "set_biosphere_type",
    "set_code_by_activity_hash",
    "set_lognormal_loc_value",
    "set_metadata_using_single_functional_exchange",
    "sp_allocate_functional_products",
    "sp_allocate_products",
    "special",
    "split_exchanges",
    "split_simapro_name_geo",
    "strip_biosphere_exc_locations",
    "tupleize_categories",
    "update_ecoinvent_locations",
    "update_social_flows_in_older_consequential",
]


from . import special
from .biosphere import (
    drop_unspecified_subcategories,
    ensure_categories_are_tuples,
    normalize_biosphere_categories,
    normalize_biosphere_names,
    strip_biosphere_exc_locations,
)
from .csv import (
    csv_add_missing_exchanges_section,
    csv_drop_unknown,
    csv_numerize,
    csv_restore_booleans,
    csv_restore_tuples,
)
from .ecospold1_allocation import (
    clean_integer_codes,
    delete_integer_codes,
    es1_allocate_multioutput,
)
from .ecospold2 import (
    add_cpc_classification_from_single_reference_product,
    assign_single_product_as_activity,
    create_composite_code,
    delete_exchanges_missing_activity,
    delete_ghost_exchanges,
    delete_none_synonyms,
    drop_temporary_outdated_biosphere_flows,
    es2_assign_only_product_with_amount_as_reference_product,
    fix_ecoinvent_flows_pre35,
    fix_unreasonably_high_lognormal_uncertainties,
    link_biosphere_by_flow_uuid,
    link_internal_technosphere_by_composite_code,
    remove_uncertainty_from_negative_loss_exchanges,
    remove_unnamed_parameters,
    remove_zero_amount_coproducts,
    remove_zero_amount_inputs_with_no_activity,
    reparametrize_lognormal_to_agree_with_static_amount,
    set_lognormal_loc_value,
    update_social_flows_in_older_consequential,
)
from .generic import (
    add_database_name,
    assign_only_product_as_production,
    convert_activity_parameters_to_list,
    convert_uncertainty_types_to_integers,
    drop_falsey_uncertainty_fields_but_keep_zeros,
    drop_unlinked,
    link_iterable_by_fields,
    link_technosphere_by_activity_hash,
    match_against_only_available_in_given_context_tree,
    match_against_top_level_context,
    normalize_units,
    set_code_by_activity_hash,
    split_exchanges,
    tupleize_categories,
)
from .json_ld import (
    json_ld_add_activity_unit,
    json_ld_add_products_as_activities,
    json_ld_convert_unit_to_reference_unit,
    json_ld_fix_process_type,
    json_ld_get_activities_list_from_rawdata,
    json_ld_get_normalized_exchange_locations,
    json_ld_get_normalized_exchange_units,
    json_ld_label_exchange_type,
    json_ld_location_name,
    json_ld_prepare_exchange_fields_for_linking,
    json_ld_remove_fields,
    json_ld_rename_metadata_fields,
)
from .json_ld_allocation import json_ld_allocate_datasets
from .json_ld_lcia import (
    json_ld_lcia_add_method_metadata,
    json_ld_lcia_convert_to_list,
    json_ld_lcia_reformat_cfs_as_exchanges,
    json_ld_lcia_set_method_metadata,
)
from .lcia import (
    add_activity_hash_code,
    drop_unlinked_cfs,
    match_subcategories,
    rationalize_method_names,
    set_biosphere_type,
)
from .locations import update_ecoinvent_locations
from .migrations import migrate_datasets, migrate_exchanges
from .products import create_products_as_new_nodes
from .sentier import match_internal_simapro_simapro_with_unit_conversion
from .simapro import (
    change_electricity_unit_mj_to_kwh,
    fix_localized_water_flows,
    fix_zero_allocation_products,
    link_technosphere_based_on_name_unit_location,
    normalize_simapro_biosphere_categories,
    normalize_simapro_biosphere_names,
    normalize_simapro_labels_to_brightway_standard,
    override_process_name_using_single_functional_exchange,
    set_metadata_using_single_functional_exchange,
    sp_allocate_functional_products,
    sp_allocate_products,
    split_simapro_name_geo,
)
from .useeio import remove_random_exchanges, remove_useeio_products
